@@ -4,19 +4,18 @@
 //! with btui you can create beautiful text user interfaces for the terminal.
 //! To get started add `btui` as a dependency to your project:
 //! ```toml
-//! btui = "0.2.1"
+//! btui = "0.3.2"
 //! ```
 
-pub mod ft;
-pub enum Variant<P, Q> {
-    One(P),
-    Two(Q),
-}
+mod ft;
+pub use ft::{effects, print};
 
 #[cfg(test)]
 mod tests {
+    use crate::effects::Color::Black;
+    use crate::print::fg;
     #[test]
-    fn it_works() {
-        assert_eq!(2 + 2, 4);
+    fn correct_color() {
+        assert_eq!(String::from("\x1b[30m"), fg(Black));
     }
 }
